@@ -18,7 +18,7 @@ our %EXPORT_TAGS = ( 'all' => [ qw($activcount
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} }, "server_info" );
 
 our @EXPORT = qw();
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 #sub AUTOLOAD {
 #    # This AUTOLOAD is used to 'autoload' constants from the constant()
@@ -67,12 +67,12 @@ sub connect {
  my $sess_id = Xconnect($logonstring, $ccs, $trx_mode);
  $logonstring = 'x' x 40;
 
- if ( $sess_id != 0 ) {
+ if ( $sess_id eq "NO SESS" ) {
+    return undef;
+ } else {
     $self->{'sess_id'} = $sess_id;
     bless $self, 'Teradata::SQL';
     return $self;
- } else {
-    return undef;
  }
 }
 
@@ -116,7 +116,7 @@ sub open {
 
  my $req_id = Xopen($ch->{sess_id}, $sql);
 
- if ( $req_id != 0 ) {
+ if ( defined $req_id ) {
     $self->{'req_id'} = $req_id;
     bless $self, 'Teradata::SQL';
     return $self;
@@ -164,7 +164,7 @@ sub openseg {
 
  my $req_id = Xopenseg($ch->{sess_id}, $sql, $save_spl);
 
- if ( $req_id != 0 ) {
+ if ( defined $req_id ) {
     $self->{'req_id'} = $req_id;
     bless $self, 'Teradata::SQL';
     return $self;
@@ -198,7 +198,7 @@ sub openp {
 # to prepare it again.
  my $req_id = Xopenp($rh->{sess_id}, $rh->{sql}, @hvars);
 
- if ( $req_id != 0 ) {
+ if ( defined $req_id ) {
     $rh->{'req_id'} = $req_id;
     return 1;
  } else {
