@@ -305,6 +305,7 @@ void _insert_dp (
  }
 
  work[24] = '\0';  /* End of string */
+ workstart = 24;
 
   /* Build the string in the work area from right to left. */
 
@@ -351,11 +352,11 @@ double _dec_to_double (
   int     decp,
   int     decs )
 {
- long    wlong;
+ Int32   wlong;
  double  wdouble;
 
  if (decp >= 5) {
-    wlong = *((long *) dec_data);
+    wlong = *((Int32 *) dec_data);
  } else if (decp >= 3) {
     wlong = *((short *) dec_data) + 0;
  } else {		/* Precision is less than 3. */
@@ -392,10 +393,10 @@ void _dec_to_string (
   Byte * dec_data,
   int     decs )
 {
- long long int  wlonglong;
+ Int64  wlonglong;
  char   wstring[24];
 
- wlonglong = *((long long *) dec_data);
+ wlonglong = *((Int64 *) dec_data);
  sprintf(wstring, "%lld", wlonglong);
  _insert_dp(res_string, wstring, decs);
 }
@@ -440,7 +441,7 @@ int _fetch_parcel (
 {
  int    status;
  struct CliSuccessType * pcl_success_ptr;
- unsigned long int  lcl_activcount;
+ UInt32  lcl_activcount;
  struct CliFailureType * err_ptr;
 
  if (req_ptr == 0) {
@@ -710,7 +711,7 @@ int Zopenseg (
  pExtArea->seg_SPOptions_elem.d8xieLen = sizeof(D8XIELEM) + sizeof(D8XIEP);
   /* The manual says that Element Type 0 = Inline and 1 = Pointer,
      but that seems to be incorrect. We are using pointers and 0. */
- pExtArea->seg_SPOptions_elem.d8xieTyp = 0;
+ pExtArea->seg_SPOptions_elem.d8xieTyp = D8XIETP;
  pExtArea->seg_SPOptions_body.d8xiepF = PclSPOPTIONSTYPE;
  pExtArea->seg_SPOptions_body.d8xiepLn = 2;
  pExtArea->seg_SPOptions_body.d8xiepPt = &( sp_opts.SPPrintOption );
@@ -803,7 +804,8 @@ int Zexecutep_args (
  pExtArea->irqx_DataInfo_elem.d8xieLen = sizeof(D8XIELEM) + sizeof(D8XIEP);
   /* The manual says that Element Type 0 = Inline and 1 = Pointer,
      but that seems to be incorrect. We are using pointers and 0. */
- pExtArea->irqx_DataInfo_elem.d8xieTyp = 0;  /* Pointer method */
+ /**pExtArea->irqx_DataInfo_elem.d8xieTyp = 1;  Pointer method **/
+ pExtArea->irqx_DataInfo_elem.d8xieTyp = 0;
 
  pExtArea->irqx_DataInfo_body.d8xiepF = PclDATAINFO; /* Flavor */
  pExtArea->irqx_DataInfo_body.d8xiepLn = sizeof(struct ModCliDataInfoType);
@@ -900,7 +902,7 @@ int Zopenp_args (
  pExtArea->irqx_DataInfo_elem.d8xieLen = sizeof(D8XIELEM) + sizeof(D8XIEP);
   /* The manual says that Element Type 0 = Inline and 1 = Pointer,
      but that seems to be incorrect. We are using pointers and 0. */
- pExtArea->irqx_DataInfo_elem.d8xieTyp = 0;  /* Pointer method */
+ pExtArea->irqx_DataInfo_elem.d8xieTyp = 0;
 
  pExtArea->irqx_DataInfo_body.d8xiepF = PclDATAINFO; /* Flavor */
  pExtArea->irqx_DataInfo_body.d8xiepLn = sizeof(struct ModCliDataInfoType);
