@@ -90,7 +90,7 @@ struct sSession {
 };
 
 struct sRequest {
-  long  req_num;
+  Int32  req_num;
   struct DBCAREA * dbcp;
   struct datadescr ddesc;
 };
@@ -101,8 +101,8 @@ typedef struct sRequest  Request, *pRequest;
  /* The following is the entire structure needed for the IRQ extension
     (passing values to parameterized SQL). We use two parcels:
     DataInfo and IndicData.
-    Header: IRX8. Level: 1. Element Type: 0 (pointers). */
-
+    Header: IRX8. Level: 1 for 32-bit, 0 for 64-bit.
+    Element Type: 0 (pointers). */
 struct irq_ext {
  struct D8CAIRX   irqx_header;
  struct D8XIELEM  irqx_DataInfo_elem;
