@@ -1,3 +1,4 @@
+
 # Before `make install' is performed this script should be runnable with
 # `make test'. After `make install' it should work as `perl test.pl'
 
@@ -19,6 +20,8 @@ $VERBOSE = $ENV{'TEST_VERBOSE'};
 
 use constant {
  QEPIFTSM => 3,
+ QEPIEXR  => 20,  #name is incorrect
+ QEPIEPU  => 21,
  QEPIIDE  => 39,
  QEPIDBR  => 34
 };
@@ -31,6 +34,10 @@ $bigint_ok = (Teradata::SQL::server_info($server, QEPIIDE) == 'Y');
 is_ok(1, 2);
 @dbs = Teradata::SQL::server_info($server, QEPIDBR);
 print "DBS release: @dbs\n";
+$aph = Teradata::SQL::server_info($server, QEPIEPU);
+print "APH support: $aph\n";
+$ext_resp = Teradata::SQL::server_info($server, 20);
+print "extended response support: $ext_resp\n";
 
 print "connect......................";
 $dbh = Teradata::SQL::connect($TDLOGON, 'UTF8')
@@ -182,6 +189,7 @@ $sth = $dbh->open("select * from vanity.of_vanities")
   && $sth->close;
 is_ok($errorcode == 3802, 12);
 
+
 print "disconnect...................";
 $Teradata::SQL::msglevel = 1;
 $dbh->disconnect;
